---------------------------------------------
-- 2 dgit 7seg LED Dynamic Scan
---------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity DynamicLED is
	port (
		clk : in std_logic;
		MSEG : out std_logic_vector(7 downto 0);
		MDEG : out std_logic_vector(1 downto 0)
	);
end DynamicLED;

architecture RTL of DynamicLED is
	signal BCDtemp : std_logic_vector(3 downto 0);
	signal Q : std_logic_vector(32 downto 0);

	-- call External segment decoder
	component SegLED
		port(
			BCD : in std_logic_vector(3 downto 0);
			SEG : out std_logic_vector(7 downto 0)
		);
	end component;

	begin
		-- 7Segment decoder
		S1 : SegLED port map (
			BCD => BCDtemp,
			SEG => MSEG
		);
		-- process Loop clk=67.108466 MHz(2^26)
		process (clk) begin
			if (clk'event and clk = '1') then
				Q <= Q + 1;
				-- make 2 Digit BCD Counter 0.5sec interval
				if(Q(28 downto 25) = 10) then
					Q(28 downto 25) <= "0000";
					Q(32 downto 29) <= Q(32 downto 29) + 1;
					if(Q(32 downto 29) = 9) then
						Q(32 downto 29) <= "0000";
					end if;
				end if;
			end if;
			-- Switch Upper/Lower
			if(Q(17) = '1') then
				BCDtemp <= Q(28 downto 25);
			else
				BCDtemp <= Q(32 downto 29);
			end if;
		end process;
		-- Set Digit Drive
		MDEG(0) <= Q(18) and Q(17);
		MDEG(1) <= Q(18) and not Q(17);
end RTL;